# eric7.Plugins.PluginWizardEricPlugin

Module implementing the eric plug-in wizard plug-in.

### Global Attributes

__header__
error

### Classes

WizardEricPluginWizard | Class implementing the eric plug-in wizard plug-in.

### Functions

None

## WizardEricPluginWizard

Class implementing the eric plug-in wizard plug-in.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

WizardEricPluginWizard | Constructor
__callForm | Private method to display a dialog and get the code.
__handle | Private method to handle the wizards action.
__initAction | Private method to initialize the action.
__initMenu | Private method to add the actions to the right menu.
__initialize | Private slot to (re)initialize the plug-in.
activate | Public method to activate this plug-in.
deactivate | Public method to deactivate this plug-in.

### Static Methods

None

#### WizardEricPluginWizard (Constructor)

WizardEricPluginWizard(ui)

Constructor

ui (UserInterface)
  reference to the user interface object

#### WizardEricPluginWizard.__callForm

__callForm()

Private method to display a dialog and get the code.

Return:
  generated code, the plug-in package name and a flag indicating success

Return Type:
  tuple of (str, str, bool)

#### WizardEricPluginWizard.__handle

__handle()

Private method to handle the wizards action.

#### WizardEricPluginWizard.__initAction

__initAction()

Private method to initialize the action.

#### WizardEricPluginWizard.__initMenu

__initMenu()

Private method to add the actions to the right menu.

#### WizardEricPluginWizard.__initialize

__initialize()

Private slot to (re)initialize the plug-in.

#### WizardEricPluginWizard.activate

activate()

Public method to activate this plug-in.

Return:
  tuple of None and activation status

Return Type:
  bool

#### WizardEricPluginWizard.deactivate

deactivate()

Public method to deactivate this plug-in.

Up